#
# spec file for package archivemount
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           archivemount
Version:        0.9.1
Release:        2.11
Summary:        Mounts an archive for access as a file system
License:        LGPL-2.1-or-later AND BSD-2-Clause
URL:            https://www.cybernoia.de/software/archivemount.html
Source:         https://www.cybernoia.de/software/archivemount/%{name}-%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  fuse-devel
BuildRequires:  libarchive-devel
BuildRequires:  pkgconfig

%description
Archivemount is a piece of glue code between libarchive (http://code.google.com/p/libarchive/) and FUSE
(http://fuse.sourceforge.net). It can be used to mount a (possibly compressed) archive (as in .tar.gz or
.tar.bz2) and use it like an ordinary filesystem.

%prep
%autosetup

%build
autoreconf --force --install
export CFLAGS="%{optflags}"
%configure
%make_build

%install
%make_install

%files
%license COPYING
%doc CHANGELOG README
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}

%changelog
* Thu Apr 22 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Fixed SPEC file: Replaced broken URL with working upstream URL.
* Sat Sep 12 2020 Matthias Eliasson <elimat@opensuse.org>
- Update to version 0.9.1
  * Incorporated fixes for compilation problems with newer gcc
    versions. Contributed by Niels de Vos
- includes 0.9.0
  * Make sure the written archive's format is the same or as
    close as possible to the original. Due to a bug written files
    were always in ustar format. Contributed by Jeff Ebert.
  * Add AM_PROG_CC_C_O macro to configure.ac, contributed by
    Jeff Ebert
  * added option -o password, contributed by Scott Worley
  * Pass REG_ENHANCED to regcomp where available (Mac and BSD).
    Otherwise \? has no special meaning. Contributed by Michael
    J. Walsh
  * Removed magic number for block size, it's a constant now.
    Contributed by John Delgado
- includes 0.8.12
  * changed naming scheme of temporary files to avoid running
    into too long names for the filesystem in /tmp
  * fixed renaming a newly created file (it got saved under its
    original name)
  * activated code for creating symlinks; in old versions, symlinks
    were not saved, presumably due to a bug in libarchive, but it
    seems to work now.
- includes 0.8.11
  * fixed accidentally broken renaming of files
- includes 0.8.10
  * fixed renaming of directories, it did not work at all anymore
- includes 0.8.9
  * fixed wrong insert into tree when a subdir had the same name as its
    parent dir
- includes 0.8.8
  * fixed bug when creating a new file and moving it over an old one,
    happens e.g. when saving a file from the geany editor
- drop patch archivemount.dif, fixed upstream
- run spec-cleaner
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Sat Feb  3 2018 avindra@opensuse.org
- Update to version 0.8.7
  * corrected an ifdef
- includes 0.8.6
  * adaptions for CentOS, RHEL and Scientific Linux
- cleanup with spec-cleaner
- rebase archivemount.dif
  * dropped fchdir fix, merged upstream in
    6839a38b570794d890ae1f0d94b41a2f0b7d23d2
- simplify CFLAGS handling
* Wed Nov 11 2015 p.drouand@gmail.com
- Update to version 0.8.5
  * FormatRaw optimization
  * bugfix : use of off_t to support 64bits
- Update archivemount-0.8.4.dif > archivemount.dif
* Sun Mar 22 2015 mpluskal@suse.com
- Update to 0.8.4
  * added option -o formatraw for readonly support of the
    FormatRaw archive files supported by libarchive (kudos to Lee
    Leahu)
  * bugfix: do not do the fuse mount when the archive cannot be read
    (also kudos to Lee Leahu)
- Cleanup spec file with spec-cleaner
- Adapt patch to upstream changes
  * archivemount-0.8.3.dif to archivemount-0.8.4.dif
* Tue Dec 16 2014 p.drouand@gmail.com
- Update to version 0.8.3
  + do not call fuse_main anymore
  + force fuse into single-threaded mode due to libarchive not being
  thread-safe
- Adapt patch to upstream changes
  + archivemount-0.6.2.607cd0d.dif  > archivemount-0.8.3.dif
- Use download Url as source
- Remove redundant %%clean section
* Mon Oct 22 2012 werner@suse.de
- Update ot current github version 0.6.2.607cd0d (including BSD-2-Clause
  licensed header file uthash.h in source tar ball)
  + Based on version 0.6.2
  + Added annotations to some variables to indicate what lock should wrap
  + Refactored the trash to not be malloced each time it is used. Instead
  + Moved the lock creation up, to ensure the fd variable is always wrapp
  + Fixed a incorrect error check.
  + Added trace logging.
  + Changed the main locking mechansim to pthread_mutex_lock from pthread
  + Cleaned up some unused variables.
  + Cleaned up some comments used during benchmarking.
  + Fixed some minor error handling conditions, spotted by the awesome cl
  + Added some brackets to avoid paranoid complier warnings.
  + Bumped the _XOPEN_SOURCE version so pthread_mutex_timedlock could be
  + Fixed the link to libarchive.
  + Changed the open operation to create a new private archive reader obj
  + Ensure st_blocks, st_blksize are set when returned from archive_entry
  + Use a full struct stat when running readdir.
  + Add missing return type. Most likely from a typo.
  + Ensure free_node() cleans up all children.
  + Changed the main data structure from a double link list, to a hash ta
  + Fixed log() lines that had more arguments than used in the format str
  + Store the basename of a file in the Node struct. This speeds up build
  + Store a pointer to the last child in a directory. This makes insertin
  + Moved archive_entry_new into init_node. This again simplifies the cod
  + Rearranged the build_tree code to avoid a call to archive_entry_clone
  + Added a new free_node function to simplify freeing nodes.
  + Changed init_node to malloc a NODE and return it. This simplied the c
* Tue May 15 2012 werner@suse.de
- Add -pthread to the gcc command line
* Mon May  7 2012 werner@suse.de
- Enforce usage of reentrant versions of libc functions
- Fix off by one error by providing enough room for the ascii zero
  as well as for the new slash
- Avoid crash even if str(r)chr does not find a slash
* Thu Dec  8 2011 cfarrell@suse.com
- license update: LGPL-2.1+
  Package is LGPL-2.1+ according to the COPYING file. Use SPDX format
* Tue Dec  6 2011 werner@suse.de
- Initial package archivemount for openSUSE
